package com.mihnita.coderefbug;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

import net.sf.okapi.common.resource.Code;
import net.sf.okapi.common.resource.TextFragment;
import net.sf.okapi.common.resource.TextFragment.TagType;

@RunWith(JUnit4.class)
@SuppressWarnings("static-method")
public class TestCodeBug {
	static private final String STRING_WITH_REF =
			"Some " + TextFragment.REFMARKER_START + " text";

	// setData(value) sets the ref flag if value contains a ref marker,
	// but does not clear it if value does not contain a ref marker.
	@Test
	public void testSetData() {
		Code c = new Code();
		assertFalse(c.hasReference()); // false, as expected
		c.setData(STRING_WITH_REF);
		assertTrue(c.hasReference()); // true, as expected
		c.setData(""); // clear the data, the ref flag would also need to be cleared, but it is not
		assertFalse(c.hasReference()); // fails
	}

	// setData sets the ref flag, but append does not
	@Test
	public void testAppendData() {
		Code c1 = new Code();
		c1.setData(STRING_WITH_REF);
		assertTrue(c1.hasReference()); // true, as expected

		Code c2 = new Code();
		c2.append(STRING_WITH_REF);
		assertTrue(c2.hasReference()); // should be true, as append / set on an empty data should be equivalent
	}

	// Constructing a Code with ref data does not set the ref flag
	@Test
	public void testConstructor() {
		// Construct without data, then set the date, ref flat == true 
		Code c1 = new Code(TagType.PLACEHOLDER, "ph");
		c1.setData(STRING_WITH_REF);
		assertTrue(c1.hasReference()); // this passes

		// Construct directly with data, ref flag == false
		Code c2 = new Code(TagType.PLACEHOLDER, "ph", STRING_WITH_REF);
		assertTrue(c2.hasReference()); // this fails
	}
}
